<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xsl:output 
        method="html" 
        indent="yes" 
        encoding="UTF-8" 
        doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"
        doctype-system="http://www.w3.org/TR/html4/loose.dtd" />

  <!--
    JANIS Import Log
  -->

  <xsl:decimal-format decimal-separator="." grouping-separator="," />

  <xsl:key name="list_exceptions1" match="exception" use="concat(@class,'|',@msg1)" />
  <xsl:key name="list_exceptions2" match="exception" use="concat(@class,'|',@msg1,'|',@msg2)" />
  <xsl:key name="list_warnings1" match="warning" use="@msg1" />
  <xsl:key name="list_warnings2" match="warning" use="concat(@msg1,'|',@msg2)" />

  <xsl:template match="/">
    <html>
      <head>
        <title>JANIS Import Log</title>
        <style type="text/css">
          .bannercell { 
            border: 0px; padding: 0px; 
          } 
          body { 
            margin: 0; 
            font:normal 100% arial,helvetica,sanserif; 
            background-color:#FFFFFF; 
            color:#000000; 
          } 
          .hiddenlink { 
            color: black; 
            text-decoration: none; 
          }
          
          table.status { 
            font:bold 80% arial,helvetica,sanserif; 
            background-color:#525D76; 
            color:#ffffff; 
          } 
          table.log tr td, tr th { 
            font-size: 80%; 
          }
          .error { 
            color:white; 
            font:bold; 
            background-color: #FF0000; 
          } 
          .warn { 
            color:brown; 
            background-color: #FFFF00; 
          } 
          .info { color:gray; }
          .debug { color:gray; } 
          .a td { background: #efefef; } 
          .b td { background: #fff; }

          .red { background: #ff5555; } 
          .lightred { background: #ffcccc; } 
          .yellow{ background: #ffff55; } 
          .lightyellow { background: #ffffcc; }
          .green { background: #55ff55; } 
          .lightgreen { background: #ccffcc; }

          th, td { text-align: left; vertical-align: top; } 
          th { background: #ccc; color: black; } 
          table, th, td { border: none }
           
          .h td { 
            font:bold 120% arial,helvetica,sanserif; 
            text-align: center; 
            background: #525D76; 
            color: white; 
            text-decoration: none; 
            padding: 6px; 
            margin-right: 2px; 
            margin-left: 2px; 
            margin-top: 0; 
            margin-bottom: 0; 
          } 
          
          h3 { 
            font:bold 80% arial,helvetica,sanserif; 
            background: #525D76; color: white; 
            text-decoration: none; 
            padding: 5px; 
            margin-right: 2px; 
            margin-left: 2px;
             margin-bottom: 0; 
          } 
          .trace { 
            font: 70% arial,helvetica,sanserif; 
            margin-left: 20px; 
          }
          
          .popup {
              position: absolute;
              visibility: hidden;
              width: 600px;
              left: 20px;
              background-color: #FFFAD5;
              border: 1px solid #000;
              padding: 10px;
          }
          
          .popup .small {
              font-size: 8pt;
          }
          
          .popup .stacktrace {
              font-size: 8pt;
              white-space: pre;
          }
        </style>
        <script type="text/javascript">
            function toggleVisible(id) {
                obj = this.document.getElementById(id);
                if (obj.style.visibility == 'visible') {
                    obj.style.visibility = 'hidden';
                } else {
                    obj.style.visibility = 'visible';
                }
            }
        </script>
      </head>
      <body>
        <table border="0" width="100%">
          <tr><td><hr noshade="noshade" size="1" /></td></tr>
        </table>

        <!-- title -->
        <table border="1" cellspacing="0" cellpadding="0" width="100%" style="font-size:120%">
          <tr class="h">
            <td>JANIS Import Log<br />
            <span style="font-size:50%"><xsl:value-of select="/importlog/@timestamp" /></span></td>
          </tr>
        </table>

        <xsl:apply-templates select="importlog" />

        <!-- footer -->
        <table width="100%">
          <tr><td><hr noshade="noshade" size="1" /></td></tr>
          <tr>
            <td>
              <div align="center">
                <font color="#525D76" size="-1">
                  <em>JANIS Import Log</em> - 
                  <xsl:value-of select="/importlog/@timestamp" />
                </font>
              </div>
            </td>
          </tr>
        </table>
      </body>
    </html>
  </xsl:template>


  <xsl:variable name="warnings_count" select="count(/importlog/warning)" />
  <xsl:variable name="exceptions_count" select="count(/importlog/exception)" />
  <xsl:variable name="statistics_count" select="count(/importlog/statistics/counts/entry)" />

  <xsl:template match="importlog">

    <!-- Index chapter -->
    <table border="1" cellspacing="2" cellpadding="3" width="100%" style="font-size:80%">

      <tr class="lightred">
        <td colspan="2">
          <b>
            <xsl:copy-of select="$exceptions_count" />
            Errors
          </b>
        </td>
      </tr>
      <tr class="lightyellow">
        <td colspan="2">
          <b>
            <xsl:copy-of select="$warnings_count" />
            Warnings
          </b>
        </td>
      </tr>

      <!-- exceptions -->
      <xsl:for-each select="/importlog/exception[generate-id(.)=generate-id(key('list_exceptions1', concat(@class,'|',@msg1)))]">
        <xsl:sort />
        <tr>
          <td class="red" width="30%">
            <xsl:value-of select="count(key('list_exceptions1',concat(@class,'|',@msg1)))" />
            x
            <xsl:value-of select="@class" />
            <br />
            <xsl:if test="@msg1 != 'null'">
              <b>
                <xsl:value-of select="@msg1" />
              </b>
            </xsl:if>
          </td>
          <td class="lightred">
            <xsl:for-each select="key('list_exceptions1',concat(@class,'|',@msg1))">
              <xsl:sort />
              <xsl:for-each select="current()[generate-id(.)=generate-id(key('list_exceptions2', concat(@class,'|',@msg1,'|',@msg2)))]">
                <xsl:sort />
                <xsl:if test="position() = 1">
                  <xsl:if test="@msg2 != 'null'">
                    <b>
                      <xsl:value-of select="@msg2" />
                    </b>
                  </xsl:if>
                  <em> in </em>
                </xsl:if>
                <xsl:for-each select="key('list_exceptions2',concat(@class,'|',@msg1,'|',@msg2))">
                  <xsl:sort />
                  <xsl:if test="position() &gt; 1">, </xsl:if>
                  <xsl:variable name="popup_id" select="generate-id()"/> 
                  <div class="popup" id="{$popup_id}">
                    <a style="float: right" href="javascript:toggleVisible('{$popup_id}')">Close</a>
                    <b><xsl:call-template name="refs" /></b><br/>
                    <span class="small">
                    <b>File:</b>:
                    <xsl:value-of select="position/@file" /><br/> 
                    <b>Line:</b>:
                    <xsl:value-of select="position/@line" /><br/>
                    <b>Offset:</b>:
                    <xsl:value-of select="position/@offset" /><br/>
                    </span>
                    <b>Stacktrace:</b><br/>
                    <div class="stacktrace">
                    <xsl:value-of select="stacktrace" />
                    </div>
                  </div>
                  <a class="hiddenlink" href="javascript:toggleVisible('{$popup_id}')">
                    <xsl:call-template name="refs" />
                  </a>
                </xsl:for-each>
                <br />
              </xsl:for-each>
            </xsl:for-each>
          </td>
        </tr>
      </xsl:for-each>

      <!-- warnings -->
      <xsl:for-each select="/importlog/warning[generate-id(.)=generate-id(key('list_warnings1', @msg1))]">
        <xsl:sort select="@msg1" />
        <tr>
          <td class="yellow" width="30%">
            <xsl:value-of select="count(key('list_warnings1',@msg1))" />
            x
            <b>
              <xsl:value-of select="@msg1" />
            </b>
          </td>
          <td class="lightyellow">
            <xsl:for-each select="key('list_warnings1',@msg1)">
              <xsl:sort select="@msg1" />
              <xsl:for-each select="current()[generate-id(.)=generate-id(key('list_warnings2', concat(@msg1,'|',@msg2)))]">
                <xsl:sort />
                <xsl:if test="position() = 1">
                  <xsl:if test="@msg2 != 'null'">
                    <b>
                      <xsl:value-of select="@msg2" />
                    </b>
                  </xsl:if>
                  <em> in </em>
                </xsl:if>
                <xsl:for-each select="key('list_warnings2',concat(@msg1,'|',@msg2))">
                  <xsl:sort />
                  <xsl:if test="position() &gt; 1">, </xsl:if>
                  <xsl:variable name="popup_id" select="generate-id()"/> 
                  <div class="popup" id="{$popup_id}">
                    <a style="float: right" href="javascript:toggleVisible('{$popup_id}')">Close</a>
                    <b><xsl:call-template name="refs" /></b><br/>
                    <span class="small">
                    <b>File:</b>:
                    <xsl:value-of select="position/@file" /><br/> 
                    <b>Line:</b>:
                    <xsl:value-of select="position/@line" /><br/> 
                    <b>Offset:</b>:
                    <xsl:value-of select="position/@offset" /><br/>
                    </span>
                  </div>
                  <a class="hiddenlink" href="javascript:toggleVisible('{$popup_id}')">
                    <xsl:call-template name="refs" />
                  </a>
                </xsl:for-each>
                <br />
              </xsl:for-each>
            </xsl:for-each>
          </td>
        </tr>
      </xsl:for-each>

 
 
      <!-- statistics -->
      <xsl:for-each select="/importlog/statistics/counts/level1">
        <xsl:sort select="@key" />
        <tr>
          <td class="green" width="30%">
            <b><xsl:value-of select="@key" /></b><br/>
            count=<xsl:value-of select="count(./level2)" /><br/>
            sum=<xsl:value-of select="sum(./level2/@count)" /><br/>
          </td>
          <td class="lightgreen">
          <xsl:for-each select="level2">
            <xsl:sort select="@count" data-type="number" order="descending" />
            <b>
              <xsl:value-of select="@count" />
              x
              <xsl:value-of select="@key" />
            </b>
            <em> in </em>
            <xsl:call-template name="refs" />
            <br />
          </xsl:for-each>
          </td>
        </tr>
    </xsl:for-each>

    </table>

  </xsl:template>


  <!--
    ***********************************************************************************************************************
    Exceptions
    ***********************************************************************************************************************
  -->

  <xsl:template match="exception">

    <a>
      <xsl:attribute name="name"><xsl:value-of select="concat('exception_', position())" />
            </xsl:attribute>
      <hr></hr>
      <!--      <h4><xsl:value-of select="@message"/></h4> -->
    </a>

    <!-- navigation -->
    <table border="1" cellspacing="2" cellpadding="3" width="100%" style="font-size:80%">
      <tr class="red">
        <td width="1">
          <xsl:value-of select="concat(position(), '/', $exceptions_count)" />
        </td>
        <td width="1">
          <a>
            <xsl:attribute name="href"><xsl:value-of select="concat('#list_exception_', position())" />
                        </xsl:attribute>
            list
          </a>
        </td>
        <xsl:choose>
          <xsl:when test="position() &gt; 1">
            <td width="1">
              <a>
                <xsl:attribute name="href"><xsl:value-of select="concat('#exception_', position()-1)" />
                                </xsl:attribute>
                &lt;&lt;
              </a>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td width="1">&lt;&lt;</td>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
          <xsl:when test="position() &lt; $exceptions_count">
            <td width="1">
              <a>
                <xsl:attribute name="href"><xsl:value-of select="concat('#exception_', position()+1)" />
                                </xsl:attribute>
                &gt;&gt;
              </a>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td width="1">&gt;&gt;</td>
          </xsl:otherwise>
        </xsl:choose>
        <td>
          <b>
            <xsl:value-of select="concat(@class, ' : ', @msg1, ' : ', @msg2)" />
          </b>
        </td>
      </tr>
    </table>

    <table class="lightred" border="1" cellspacing="2" cellpadding="3" width="100%" style="font-size:80%">
      <xsl:apply-templates select="refs" />
      <xsl:apply-templates select="position" />
      <xsl:apply-templates select="stacktrace" />
    </table>

  </xsl:template>


  <!--
    ***********************************************************************************************************************
    Warnings
    ***********************************************************************************************************************
  -->

  <xsl:template match="warning">

    <a>
      <xsl:attribute name="name"><xsl:value-of select="concat('warning_', position())" />
            </xsl:attribute>
      <hr></hr>
      <!--      <h4><xsl:value-of select="@message"/></h4> -->
    </a>

    <!-- navigation -->
    <table border="1" cellspacing="2" cellpadding="3" width="100%" style="font-size:80%">
      <tr class="yellow">
        <td width="1">
          <xsl:value-of select="concat(position(), '/', $warnings_count)" />
        </td>
        <td width="1">
          <a>
            <xsl:attribute name="href"><xsl:value-of select="concat('#list_warning_', position())" />
                        </xsl:attribute>
            list
          </a>
        </td>
        <xsl:choose>
          <xsl:when test="position() &gt; 1">
            <td width="1">
              <a>
                <xsl:attribute name="href"><xsl:value-of select="concat('#warning_', position()-1)" />
                                </xsl:attribute>
                &lt;&lt;
              </a>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td width="1">&lt;&lt;</td>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
          <xsl:when test="position() &lt; $warnings_count">
            <td width="1">
              <a>
                <xsl:attribute name="href"><xsl:value-of select="concat('#warning_', position()+1)" />
                                </xsl:attribute>
                &gt;&gt;
              </a>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td width="1">&gt;&gt;</td>
          </xsl:otherwise>
        </xsl:choose>
        <td>
          <b>
            <xsl:value-of select="@message" />
          </b>
        </td>
      </tr>
    </table>

    <table class="lightyellow" border="1" cellspacing="2" cellpadding="3" width="100%" style="font-size:80%">
      <xsl:apply-templates select="refs" />
      <xsl:apply-templates select="position" />
    </table>

  </xsl:template>



  <!--
    ***********************************************************************************************************************
    Statistics
    ***********************************************************************************************************************
  -->

  <xsl:template match="statistics/counts/entry">

    <a>
      <xsl:attribute name="name">
            <xsl:value-of select="concat('stats_counts_', position())" />
        </xsl:attribute>
      <hr></hr>
      <!--      <h4><xsl:value-of select="@message"/></h4> -->
    </a>

    <!-- navigation -->
    <table border="1" cellspacing="2" cellpadding="3" width="100%" style="font-size:80%">
      <tr class="green">
        <td width="1">
          <a>
            <xsl:attribute name="href"><xsl:value-of select="concat('#list_stats_counts_', position())" />
                        </xsl:attribute>
            list
          </a>
        </td>
        <xsl:choose>
          <xsl:when test="position() &gt; 1">
            <td width="1">
              <a>
                <xsl:attribute name="href"><xsl:value-of select="concat('#stats_counts_', position()-1)" />
                                </xsl:attribute>
                &lt;&lt;
              </a>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td width="1">&lt;&lt;</td>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
          <xsl:when test="position() &lt; $statistics_count">
            <td width="1">
              <a>
                <xsl:attribute name="href"><xsl:value-of select="concat('#stats_counts_', position()+1)" />
                                </xsl:attribute>
                &gt;&gt;
              </a>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td width="1">&gt;&gt;</td>
          </xsl:otherwise>
        </xsl:choose>
        <td width="1">
          <xsl:value-of select="@count" />
        </td>
        <td>
          <b>
            <xsl:value-of select="@key" />
          </b>
        </td>
      </tr>
    </table>

    <table class="lightgreen" border="1" cellspacing="2" cellpadding="3" width="100%" style="font-size:80%">
      <xsl:apply-templates select="refs" />
    </table>

  </xsl:template>



  <!--
    ***********************************************************************************************************************
    XForms shared by exceptions, warnings and statistics
    ***********************************************************************************************************************
  -->

  <xsl:template match="position">
    <tr>
      <td width="1">File</td>
      <td>
        <xsl:value-of select="@file" />
        zip=
        <xsl:value-of select="@zip" />
        line=
        <xsl:value-of select="@line" />
        offset=
        <xsl:value-of select="@offset" />
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="stacktrace">
    <tr>
      <td width="1">Stacktrace</td>
      <td>
        <pre class="trace">
          <xsl:value-of select="." />
        </pre>
      </td>
    </tr>
  </xsl:template>



  <!--
    ***********************************************************************************************************************
    FormatRefs
    ***********************************************************************************************************************
  -->

  <xsl:template name="refs">
    <xsl:apply-templates select="endfrefs" />
    <xsl:apply-templates select="nubaserefs" />
    <xsl:apply-templates select="gendfrefs" />
    <xsl:apply-templates select="interrefs" />
    <xsl:apply-templates select="exforrefs" />
    <xsl:apply-templates select="cindarefs" />
    <xsl:apply-templates select="boxerrefs" />
    <xsl:apply-templates select="errorrrefs" />
  </xsl:template>

  <xsl:template match="nubaserefs">
    Z=
    <xsl:value-of select="@z" />
    A=
    <xsl:value-of select="@a" />
    State=
    <xsl:value-of select="@state" />
  </xsl:template>

  <xsl:template match="endfrefs">
    Z=
    <xsl:value-of select="@z" />
    A=
    <xsl:value-of select="@a" />
    State=
    <xsl:value-of select="@state" />
    MF=
    <xsl:value-of select="@mf" />
    MT=
    <xsl:value-of select="@mt" />
    MAT=
    <xsl:value-of select="@mat" />
    NLIB,NVER=
    <xsl:value-of select="@nlib_nver" />
    NSUB=
    <xsl:value-of select="@nsub" />
    NMOD=
    <xsl:value-of select="@nmod" />
  </xsl:template>

  <xsl:template match="gendfrefs">
    Z=
    <xsl:value-of select="@z" />
    A=
    <xsl:value-of select="@a" />
    State=
    <xsl:value-of select="@state" />
    MF=
    <xsl:value-of select="@mf" />
    MT=
    <xsl:value-of select="@mt" />
    MAT=
    <xsl:value-of select="@mat" />
    TEMP=
    <xsl:value-of select="@temp" />
  </xsl:template>

  <xsl:template match="errorrrefs">
    Z=
    <xsl:value-of select="@z" />
    A=
    <xsl:value-of select="@a" />
    State=
    <xsl:value-of select="@state" />
    MAT=
    <xsl:value-of select="@mat" />
    MF=
    <xsl:value-of select="@mf" />
    MT=
    <xsl:value-of select="@mt" />
  </xsl:template>

  <xsl:template match="boxerrefs">
    ITYPE=
    <xsl:value-of select="@itype" />
    MAT=
    <xsl:value-of select="@mat" />
    MT=
    <xsl:value-of select="@mt" />
    MAT1=
    <xsl:value-of select="@mat1" />
    MT1=
    <xsl:value-of select="@mt1" />
  </xsl:template>

  <xsl:template match="interrefs">
    Z=
    <xsl:value-of select="@z" />
    A=
    <xsl:value-of select="@a" />
    liso=
    <xsl:value-of select="@liso" />
    MT=
    <xsl:value-of select="@mt" />
    library=
    <xsl:value-of select="@library" />
  </xsl:template>

  <xsl:template match="exforrefs">
    <xsl:value-of select="concat(@accession_number, '.', format-number(@subaccession_number, '000'))" />
  </xsl:template>

  <xsl:template match="cindarefs">
    <xsl:value-of select="concat(@block_number, '-', @sequence)" />
  </xsl:template>

</xsl:stylesheet>
